class JSONSchemaQuerySetMixin():
    def _setup(self):
        # find all JSONFieldMixin fields
        pass

    def _substitute_keys(self, keys):
        pass

    def filter(self):
        pass

    def order_by(self):
        pass
